searchData={"content_type":"text/markdown","items":[{"doc":"","ref":"OpenGraph.html","title":"OpenGraph","type":"module"},{"doc":"Fetch URL and parse Open Graph protocol.\n\nReturns `{:ok, %OpenGraph{}}` for succussful request, otherwise, returns `{:error, %OpenGraph.Error{}}`.","ref":"OpenGraph.html#fetch/2","title":"OpenGraph.fetch/2","type":"function"},{"doc":"Similar to `fetch/2` but raises an `OpenGraph.Error` if request failed.\n\nReturns `%OpenGraph{}`.","ref":"OpenGraph.html#fetch!/2","title":"OpenGraph.fetch!/2","type":"function"},{"doc":"Parse Open Graph protocol.\n\nReturns `%OpenGraph{}`.","ref":"OpenGraph.html#parse/1","title":"OpenGraph.parse/1","type":"function"},{"doc":"iex> OpenGraph.parse(\" \")\n    %OpenGraph{title: \"GitHub\"}","ref":"OpenGraph.html#parse/1-examples","title":"Examples - OpenGraph.parse/1","type":"function"},{"doc":"","ref":"OpenGraph.html#t:t/0","title":"OpenGraph.t/0","type":"type"},{"doc":"","ref":"OpenGraph.html#t:url/0","title":"OpenGraph.url/0","type":"type"},{"doc":"","ref":"OpenGraph.html#t:value/0","title":"OpenGraph.value/0","type":"type"},{"doc":"","ref":"OpenGraph.Error.html","title":"OpenGraph.Error","type":"exception"},{"doc":"","ref":"OpenGraph.Error.html#t:reason/0","title":"OpenGraph.Error.reason/0","type":"type"},{"doc":"","ref":"OpenGraph.Error.html#t:status_code/0","title":"OpenGraph.Error.status_code/0","type":"type"},{"doc":"","ref":"OpenGraph.Error.html#t:t/0","title":"OpenGraph.Error.t/0","type":"type"},{"doc":"# ogp\n\nThe [Open Graph protocol](https://ogp.me/) library in Elixir.\n\n[![CI](https://github.com/goofansu/ogp/actions/workflows/ci.yml/badge.svg)](https://github.com/goofansu/ogp/actions/workflows/ci.yml)\n[![Coverage Status](https://coveralls.io/repos/github/goofansu/ogp/badge.svg?branch=main)](https://coveralls.io/github/goofansu/ogp?branch=main)\n[![Version](https://img.shields.io/hexpm/v/ogp.svg)](https://hex.pm/packages/ogp)","ref":"readme.html","title":"ogp","type":"extras"},{"doc":"```elixir\ndef deps do\n  [\n    {:ogp, \"~> 1.1.0\"}\n  ]\nend\n```","ref":"readme.html#installation","title":"Installation - ogp","type":"extras"},{"doc":"It is recommended to run [ogp.livemd](https://github.com/goofansu/ogp/blob/main/ogp.livemd) in [Livebook](https://github.com/elixir-nx/livebook) for more details.","ref":"readme.html#usage","title":"Usage - ogp","type":"extras"},{"doc":"```elixir\niex> html = \"\"\"\n \n \n \n \n \n \n \n \n \n \n \n \n\"\"\"\niex> OpenGraph.parse(html)\n%OpenGraph{\n  audio: \"https://example.com/bond/theme.mp3\",\n  description: \"Sean Connery found fame and fortune as the\\n           suave, sophisticated British agent, James Bond.\",\n  determiner: \"the\",\n  image: \"https://ia.media-imdb.com/images/rock.jpg\",\n  locale: \"en_GB\",\n  site_name: \"IMDb\",\n  title: \"The Rock\",\n  type: \"video.movie\",\n  url: \"https://www.imdb.com/title/tt0117500/\",\n  video: \"https://example.com/bond/trailer.swf\"\n}\n```","ref":"readme.html#parse-html","title":"Parse HTML - ogp","type":"extras"},{"doc":"```elixir\niex> OpenGraph.fetch!(\"https://github.com\")\n%OpenGraph{\n  audio: nil,\n  description: \"GitHub is where over 65 million developers shape the future of software, together. Contribute to the open source community, manage your Git repositories, review code like a pro, track bugs and feat...\",\n  determiner: nil,\n  image: \"https://github.githubassets.com/images/modules/site/social-cards/github-social.png\",\n  locale: nil,\n  site_name: \"GitHub\",\n  title: \"GitHub: Where the world builds software\",\n  type: \"object\",\n  url: \"https://github.com/\",\n  video: nil\n}\n```\n\nRedirects are followed automatically by default.\n\n```elixir\niex> OpenGraph.fetch!(\"https://producthunt.com\")\n\n[debug] redirecting to https://www.producthunt.com/\n%OpenGraph{\n  title: \" Product Hunt – The best new products in tech. \",\n  type: \"article\",\n  image: \"https://ph-static.imgix.net/ph-logo-1.png\",\n  url: \"https://www.producthunt.com/\",\n  audio: nil,\n  description: \"Product Hunt is a curation of the best new products, every day. Discover the latest mobile apps, websites, and technology products that everyone's talking about.\",\n  determiner: nil,\n  locale: \"en_US\",\n  site_name: \"Product Hunt\",\n  video: nil\n}\n```\n\nYou can control redirects by configuring `req_options`.\n\n- Disable redirects:\n\n```elixir\nconfig :ogp,\n  req_options: [\n    redirect: false\n  ]\n```\n\n- Set a different `max_redirects` (default is `10`):\n\n```elixir\nconfig :ogp,\n  req_options: [\n    max_redirects: 3\n  ]\n```\n\nSee https://hexdocs.pm/req/Req.html#new/1-options for the full `req` options.","ref":"readme.html#fetch-url","title":"Fetch URL - ogp","type":"extras"}],"producer":{"name":"ex_doc","version":[48,46,51,52,46,50]}}